@@ -1323,9 +1323,17 @@ class GeoArray(object):
                   origin='upper', transform=crs_in, extent=list(self.box.boundsMap))
 
         # show grid lines
-        # NOTE: The current version of cartopy can only label PlateCarree grid lines - (crs=crs_out) is not yet
-        #       supported and the labels are just missing in that case.
-        ax.gridlines(draw_labels=True, linewidth=2, color='gray', alpha=0.5, linestyle='--')
+        try:
+            # cartopy>=0.18.0 only
+            # NOTE: The current version of cartopy (0.18.0) can only label PlateCarree grid lines -
+            #       (crs=crs_out) is not yet supported and the labels are just missing in that case.
+            ax.gridlines(draw_labels=True, linewidth=2, color='gray', alpha=0.5, linestyle='--')
+        except TypeError as e:
+            if 'Cannot label gridlines on a _EPSGProjection plot.' in str(e):
+                warnings.warn('The grid line labels cannot be drawn with cartopy<0.18.0.')
+                ax.gridlines(draw_labels=False, linewidth=2, color='gray', alpha=0.5, linestyle='--')
+            else:
+                raise
 
         if return_map:
             return fig, ax
